// LICENSE : MIT
"use strict";

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var CLIEngine = require("eslint").CLIEngine;
var path = require("path");
var defaultOptions = {
    // path to .eslintrc file
    "configFile": null,
    // recognize lang of CodeBlock
    "langs": ["js", "javascript", "node", "jsx"]
};
var reporter = function reporter(context, options) {
    var Syntax = context.Syntax;
    var RuleError = context.RuleError;
    var report = context.report;
    var fixer = context.fixer;
    var getSource = context.getSource;

    if (!options.configFile) {
        throw new Error("Require options: { \"configFile\": \"path/to/.eslintrc\" }");
    }
    var availableLang = options.langs || defaultOptions.langs;
    var filePath = context.getFilePath();
    var textlintRcFilePath = context.config ? context.config.configFile : null;
    var textlintRCDir = textlintRcFilePath ? path.dirname(textlintRcFilePath) : process.cwd();
    var ESLintOptions = {
        configFile: path.resolve(textlintRCDir, options.configFile)
    };
    var engine = new CLIEngine(ESLintOptions);
    return _defineProperty({}, Syntax.CodeBlock, function (node) {
        if (availableLang.indexOf(node.lang) === -1) {
            return;
        }
        var raw = getSource(node);
        var code = node.value;
        var resultLinting = engine.executeOnText(code, node.lang);
        if (resultLinting.errorCount === 0) {
            return;
        }
        var results = resultLinting.results;
        results.forEach(function (result) {
            result.messages.forEach(function (message) {
                /*
                  1. ```js
                 2. CODE
                 3. ```
                  ESLint message line and column start with 1
                 */
                if (message.fix) {
                    var paddingIndex = raw.indexOf(code);
                    var fixedRange = message.fix.range;
                    var fixedText = message.fix.text;
                    var fixedWithPadding = [fixedRange[0] + paddingIndex, fixedRange[1] + paddingIndex];
                    report(node, new RuleError(message.ruleId + ": " + message.message, {
                        line: message.line,
                        column: message.column - 1,
                        fix: fixer.replaceTextRange(fixedWithPadding, fixedText)
                    }));
                } else {
                    report(node, new RuleError(message.ruleId + ": " + message.message, {
                        line: message.line,
                        column: message.column - 1
                    }));
                }
            });
        });
    });
};
module.exports = {
    linter: reporter,
    fixer: reporter
};
//# sourceMappingURL=textlint-rule-eslint.js.map